@@ -1,5 +1,5 @@
 import attr
-from datetime import date, datetime
+from datetime import date
 from typing import Optional
 from uuid import UUID
 
